.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

============================
collective.behavior.altimage
============================

Behavior for having an alternative image.
Useful for having for example a lead image that you use in listings,
and an alternative image that you use in the page header.


Installation
------------

Install collective.behavior.altimage by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.behavior.altimage


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.behavior.altimage/issues
- Source Code: https://github.com/collective/collective.behavior.altimage


Support
-------

If you are having issues, please let us know in the issue tracker.


License
-------

The project is licensed under the GPLv2.
